==> BSgenome.Scerevisiae.UCSC.sacCer1_1.3.11.tar.gz: BSgenome.Scerevisiae.UCSC.sacCer1/man/package.Rd <==
\name{Scerevisiae}
\docType{package}

\alias{BSgenome.Scerevisiae.UCSC.sacCer1-package}
\alias{BSgenome.Scerevisiae.UCSC.sacCer1}
\alias{Scerevisiae}


\title{Saccharomyces cerevisiae (Yeast) full genome (UCSC version sacCer1)}

\description{
  Saccharomyces cerevisiae (Yeast) full genome as provided by UCSC (sacCer1, Oct. 2003) and stored in Biostrings objects.
}

\details{
  
}

\note{
  This BSgenome data package was made from the following source data files:
  \preformatted{
chromFa.zip from http://hgdownload.cse.ucsc.edu/goldenPath/sacCer1/bigZips/

  }
  See \code{?\link[BSgenome]{BSgenomeForge}} and the BSgenomeForge
  vignette (\code{vignette("BSgenomeForge")}) in the BSgenome software
  package for how to make a BSgenome data package.
}

\author{H. Pages}

\seealso{
  \link[BSgenome]{BSgenome-class},
  \link[Biostrings]{DNAString-class},
  \code{\link[BSgenome]{available.genomes}},
  \link[BSgenome]{BSgenomeForge}
}

\examples{
Scerevisiae
seqlengths(Scerevisiae)
Scerevisiae$chr1  # same as Scerevisiae[["chr1"]]

if ("AGAPS" \%in\% masknames(Scerevisiae)) {

  ## Check that the assembly gaps contain only Ns:
  checkOnlyNsInGaps <- function(seq)
  {
    ## Replace all masks by the inverted AGAPS mask
    masks(seq) <- gaps(masks(seq)["AGAPS"])
    af <- alphabetFrequency(seq)
    found_letters <- names(af)[af != 0]
    if (any(found_letters != "N"))
        stop("assembly gaps contain more than just Ns")
  }

  ## A message will be printed each time a sequence is removed
  ## from the cache:
  options(verbose=TRUE)

  for (seqname in seqnames(Scerevisiae)) {
    cat("Checking sequence", seqname, "... ")
    seq <- Scerevisiae[[seqname]]
    checkOnlyNsInGaps(seq)
    cat("OK\n")
  }
}

## See the GenomeSearching vignette in the BSgenome software
## package for some examples of genome-wide motif searching using
## Biostrings and the BSgenome data packages:
if (interactive())
    vignette("GenomeSearching", package="BSgenome")
}

\keyword{package}
\keyword{data}

==> BSgenome.Scerevisiae.UCSC.sacCer1_1.3.17.tar.gz: BSgenome.Scerevisiae.UCSC.sacCer1/man/package.Rd <==
\name{Scerevisiae}
\docType{package}

\alias{BSgenome.Scerevisiae.UCSC.sacCer1-package}
\alias{BSgenome.Scerevisiae.UCSC.sacCer1}
\alias{Scerevisiae}


\title{Saccharomyces cerevisiae (Yeast) full genome (UCSC version sacCer1)}

\description{
  Saccharomyces cerevisiae (Yeast) full genome as provided by UCSC (sacCer1, Oct. 2003) and stored in Biostrings objects.
}

\details{
  
}

\note{
  This BSgenome data package was made from the following source data files:
  \preformatted{
chromFa.zip from http://hgdownload.cse.ucsc.edu/goldenPath/sacCer1/bigZips/

  }
  See \code{?\link[BSgenome]{BSgenomeForge}} and the BSgenomeForge
  vignette (\code{vignette("BSgenomeForge")}) in the BSgenome software
  package for how to make a BSgenome data package.
}

\author{H. Pages}

\seealso{
  \link[BSgenome]{BSgenome-class},
  \link[Biostrings]{DNAString-class},
  \code{\link[BSgenome]{available.genomes}},
  \link[BSgenome]{BSgenomeForge}
}

\examples{
Scerevisiae
seqlengths(Scerevisiae)
Scerevisiae$chr1  # same as Scerevisiae[["chr1"]]

if ("AGAPS" \%in\% masknames(Scerevisiae)) {

  ## Check that the assembly gaps contain only Ns:
  checkOnlyNsInGaps <- function(seq)
  {
    ## Replace all masks by the inverted AGAPS mask
    masks(seq) <- gaps(masks(seq)["AGAPS"])
    unique_letters <- uniqueLetters(seq)
    if (any(unique_letters != "N"))
        stop("assembly gaps contain more than just Ns")
  }

  ## A message will be printed each time a sequence is removed
  ## from the cache:
  options(verbose=TRUE)

  for (seqname in seqnames(Scerevisiae)) {
    cat("Checking sequence", seqname, "... ")
    seq <- Scerevisiae[[seqname]]
    checkOnlyNsInGaps(seq)
    cat("OK\n")
  }
}

## See the GenomeSearching vignette in the BSgenome software
## package for some examples of genome-wide motif searching using
## Biostrings and the BSgenome data packages:
if (interactive())
    vignette("GenomeSearching", package="BSgenome")
}

\keyword{package}
\keyword{data}
